@@ -14,8 +14,11 @@ def path_to_object(path):
 
 def split1000(s, sep=','):
     """http://www.python.org.br/wiki/FormatarNumeros"""
-    #return s if len(s) <= 3 else split1000(s[:-3], sep) + sep + s[-3:]
-    return len(s) <= 3 and s or split1000(s[:-3], sep) + sep + s[-3:]
+    minus = s.startswith('-')
+    if minus: s = s[1:]
+    res = len(s) <= 3 and s or split1000(s[:-3], sep) + sep + s[-3:]
+
+    return (minus and '-' or '') + res
 
 def get_admin_url(obj):
     from django.contrib import admin
